from .__pytransform import pyarmor_runtime

"""
# MixtureMapping

[![Documentation](https://github.com/VK/dash-express-components/workflows/Publish%20release/badge.svg)](https://vk.github.io/mixturemapping-doc)
[![PyPI version](https://badge.fury.io/py/mixturemapping.svg)](https://badge.fury.io/py/mixturemapping)

Train Gaussian Mixture Mappings


## Provides:
  1. Layers to build tensorflow models to map Gaussian mixtures
  2. Tools to compute yield values of Gaussian mixtures in complex binning schemes

## Example
  
    import mixturemapping as mm  
    import tensorflow as tf

    inMeans = tf.keras.Input(shape=(mixN, inputMixM), name="Means", dtype=dataType)
    inStdDevs = tf.keras.Input(shape=(mixN, inputMixM), name="StdDevs", dtype=dataType)
    inWeight = tf.keras.Input(shape=(mixN), name="Weights", dtype=dataType)

    mapModel = tf.keras.Sequential()
    mapModel.add( tf.keras.layers.Dense(40, activation="relu", kernel_regularizer=regularizers.l2(0.001)) )
    mapModel.add( tf.keras.layers.Dense(40, activation="relu", kernel_regularizer=regularizers.l2(0.001)) )
    mapModel.add( tf.keras.layers.Dense(outputMixM))
    y = mapModel(inMeans)

    deltaModel = tf.keras.Sequential()
    deltaModel.add( tf.keras.layers.Dense(40, activation="relu", kernel_regularizer=regularizers.l2(0.001)) )
    deltaModel.add( tf.keras.layers.Dense(40, activation="relu", kernel_regularizer=regularizers.l2(0.001)) )
    deltaModel.add( tf.keras.layers.Dense(outputMixM))
    yDelta = deltaModel(inMeans)

    covALayer = mm.layers.TrainableCovMatrix(outputMixM, name="CovA")
    covA = covALayer(inMeans)

    mapLayer = mm.layers.GeneralMapping(outputMixM, name="Mapping", dtype=dataType)
    newDist = mapLayer({'means': inMeans, 'y':y, 'yDelta':yDelta, 'stdDevs': inStdDevs, 'weights': inWeight, 'covA': covA})

    distLayer = mm.layers.Distribution(dtype=dataType, regularize_cov_epsilon=0.95)
    dist = distLayer(newDist)

### Developement
```
$ py -m venv env
$ .\env\Scripts\activate
$ pip install -r requirements.txt
```


"""


pyarmor_runtime()
__pyarmor__(__name__, __file__, b'\x50\x59\x41\x52\x4d\x4f\x52\x00\x00\x03\x07\x00\x42\x0d\x0d\x0a\x08\x2d\xa0\x01\x00\x00\x00\x00\x01\x00\x00\x00\x40\x00\x00\x00\xd0\x07\x00\x00\x00\x00\x00\x18\x67\xd8\x5d\x9c\xf3\x74\x6c\x2b\x9d\xa9\xd8\x1d\xc4\x37\xd1\xe4\x00\x00\x00\x00\x00\x00\x00\x00\xa5\x6b\x69\x63\xc8\x59\x41\xa8\xb2\xf6\x2c\xcb\x62\xfd\x8e\x6c\xfe\xdb\xc6\x9d\x26\x2e\xed\x11\xb1\x6f\xd1\x8c\xbf\x58\x54\x2d\x28\x27\x65\xe6\xec\x5c\xe7\x16\xe9\x8a\x17\x0d\xda\xb5\x49\xae\x28\x16\xe9\x15\x3a\xac\xe6\x9f\xc9\x60\x42\x49\xf0\x6d\x6a\x3f\x48\xb2\x5d\x77\x21\xca\x0c\xb1\xb8\x4b\xad\xf2\xd8\xd4\xeb\xc1\x11\x07\xfc\xfb\x92\xa6\xb1\x05\x39\x74\x15\xc5\x2e\xb0\x64\x41\xef\xe4\x82\x2e\x25\x90\x36\xa0\x62\xbf\x68\xb6\x64\xb3\x32\x2c\x22\x51\x9b\x4e\xcb\x83\x90\x1f\x7a\xf2\xef\x1b\x20\xe9\x99\xb4\x4f\x24\xb9\xbe\xdd\x92\x2c\x29\x19\x5d\x8a\x76\xaa\xb9\x86\x7c\x48\xb8\x14\x4a\x4b\x58\x33\xef\xa9\xa5\xbe\xcd\x09\x53\x26\xb5\x39\x7e\x10\x36\x54\x6d\xad\x02\xff\x93\x30\x79\xad\xbc\x77\x8f\xae\x24\x28\x54\x56\xc0\x42\x5d\x47\x7d\xac\x38\x7f\x5f\x8a\x50\x20\x4d\x64\x40\xb6\x8e\x74\xf4\x66\x26\x7b\xce\xbc\xb9\x82\xb2\xa5\xc9\xdd\x69\xc9\x08\x03\x4e\x0e\x8a\x6c\x89\x07\xe7\xc4\x69\xab\xe0\x82\xd3\x9a\x7b\x53\xc4\x90\xf0\x07\xe0\x7c\xba\x0c\x60\x15\xb4\x86\x9d\x03\x36\x01\x67\xe7\x5a\x71\x09\xdc\xfd\x92\xab\xd0\x15\xb0\x0a\x47\x95\xd6\x56\xe3\x15\xf2\xe4\x4a\x94\x88\x26\xfc\xda\x08\x36\x0d\x41\x92\x5e\x68\xfb\x14\xb1\x6e\x19\x04\xa5\x72\x22\x1c\x40\x6f\x3f\x10\x62\x3b\xea\xff\xae\x4f\xe7\x4a\xbf\x98\x37\x8b\xce\x4d\x8c\x01\x87\x15\x14\x77\x2d\x9a\xe9\x97\x4e\x97\x6c\x4d\xbf\x33\x34\xb8\x04\xd2\xcf\xa8\xa0\x30\xe8\xf4\x9f\xc5\x56\x5e\xd6\xb1\x0c\x7a\x3f\xa5\x17\x9a\x2f\xe9\x6a\xdb\x72\x92\x59\x17\xcc\x87\xb2\x6d\x16\xfa\x48\xf2\xf3\x5a\x73\xb5\xfd\xe7\x34\xc4\xeb\x43\xc9\xb6\x40\x22\x50\x69\x2a\x20\x71\x05\x92\x05\xbe\x55\xaf\x8d\xb0\xe5\xd9\xbf\xc7\xdb\xc1\xb9\x74\xad\x5e\xd7\xdd\xfb\xae\x07\xe0\x6d\x9f\xc3\xdc\x6a\x1d\x6b\xb3\xcb\x82\x37\x6d\xfd\x30\xce\xbf\xdb\xd1\x24\x4b\x38\x5e\xea\x77\x3f\x9e\xfa\x1b\xf8\x13\xc6\x76\xcf\x20\x5c\x5d\x05\xe7\xa9\x61\x0b\x74\x79\xe3\xfe\xe7\x6d\xd9\x0d\xa5\xb5\x80\x90\x30\x88\x2d\x70\x5c\x6b\xc5\x58\x1d\x68\xa7\x8d\x59\xca\xe6\x94\xf1\x25\x25\x52\x76\xb0\x1c\xac\x0a\x36\x32\xce\x74\xfd\xff\x07\x94\xcc\x4e\x5b\x72\x0f\xbc\x1a\x33\x52\xdf\x5c\xfb\x00\xff\xc9\xfe\x46\xa7\x37\x2a\x70\x3d\x2b\x3d\x33\xa6\x2d\xcd\x5e\x9d\x3e\x59\x16\x93\x4d\x77\xce\x1a\x42\x82\x65\xc1\xee\xda\x45\x58\xf5\x13\xa6\x47\x1a\xf5\xbe\x5e\x5c\x45\xf4\xdb\xac\x35\xfc\xc9\xf0\x4b\x42\x50\xa5\x41\xee\xe7\x1d\xb0\x44\x48\xb4\x2c\xe3\x34\x6c\xdf\xb3\x13\xcd\xe3\x73\x22\xe4\x3d\x2f\x1b\xcc\x23\xba\xfb\x86\x06\x6d\xda\x37\x13\x20\x5d\x45\xdb\x95\xc5\x8f\x23\x11\xd2\x35\x18\x4e\xb6\xcd\xba\xd8\xa5\x28\x8c\xf0\x49\xd1\x74\xb8\xd7\x60\x13\x06\xe1\x2b\x82\x9c\x63\x04\xd5\x35\x2d\x5d\x85\xf0\x40\x24\x61\x43\x2c\xe4\xb0\x0d\x5a\xe4\x53\xdc\x95\x15\x37\xac\x8b\x55\x7c\xe5\x1f\x96\xdf\x3c\x06\xa5\x40\xa6\xb6\xe4\x29\x4c\x81\x27\xab\xf3\x37\xc5\xa0\x1e\x55\x1c\x56\x15\x15\x16\x68\x92\xa8\x95\x36\x4d\xf5\xad\xc1\xc5\x64\x52\x55\x0c\x15\xc1\x25\x8a\x77\x4c\x6b\x57\x52\x4e\x62\xf4\xf1\x83\x94\x4c\xe7\x1b\xbc\xa2\x44\x1f\x0c\x19\xa0\xd2\xa7\x85\x06\x6d\xc2\x6b\x73\xf0\x51\x8d\x15\xfc\x45\x71\x9f\xa9\xfa\x85\x38\x3b\xae\x8a\x4a\xa9\x96\x57\xce\x62\x87\x9f\x43\xf1\x7c\x62\x3b\x20\x89\xdc\x95\xec\x56\x2a\x20\x2d\x3a\x8c\xb8\x99\x9d\xba\x97\x57\x5f\x78\x60\xaf\x75\xa8\xd8\x73\xa2\xbf\x6b\x50\xfa\xfe\xcc\xe5\x5f\x2f\x07\x39\x0d\x04\xe5\x4f\xf3\x2d\x88\x71\x3a\x0e\x4c\xd9\xbf\x99\x18\xe4\x9e\x3a\x15\xf5\x3b\x49\x25\x8a\xcd\x5a\x0a\x4d\x78\x94\x3a\x30\x65\x4f\x55\x65\x5f\x91\xe7\x9c\x69\x83\xd4\xdf\x20\x51\x37\xd2\x1a\xad\xa3\x04\x1d\xe4\x2e\x6e\x6e\x81\xeb\xc3\x31\x06\x32\xff\x34\x0f\x73\xf0\x20\xdc\x99\xe9\xa1\x5b\xb9\x65\x15\x61\x62\xd6\xb1\xd7\x9f\xbe\xa4\xcf\xa7\x52\xdd\xd5\x42\xb1\xdb\x1d\x4b\x47\x46\xfa\x0c\xff\x22\x35\xa9\x96\x09\xf6\x30\xcc\x29\x1f\x2e\x89\x64\xcc\x50\xfa\xd1\x0e\x38\xec\xea\x69\x26\x43\x88\x34\xea\xc6\x0f\xcd\x08\x7e\x68\x2d\x76\xe4\xea\x63\x3d\x90\xea\x2b\x1d\x5d\xfb\x56\x6e\xbb\x47\x5c\x81\x7d\xc2\x7d\x47\x56\xe3\x1e\xae\x5c\x7c\x3f\x0c\xc5\x2d\x80\xf0\x38\xe6\x71\xb5\x5b\x92\x30\xd8\xba\x03\x3a\x96\x6b\x79\x2e\x65\xed\x85\xd0\xd5\xda\x4e\xe3\x94\x18\xf1\xf5\xb3\x98\xbf\x64\x94\x0c\xb9\xfc\x87\x1c\x45\x15\xfe\xd1\x3d\x6f\xa8\xa6\x23\x53\xef\xfb\x47\x54\xcf\xdb\xfe\x89\x7c\x74\xb5\xf5\xe8\x31\xcd\xce\xaf\xa9\x13\x01\x3c\x71\xc4\x1f\x5c\x49\xa5\x03\xfe\x57\x50\x7d\x4a\xe8\x59\xc9\xbb\x05\x94\x09\x86\xb9\xd7\x9e\x0d\xeb\x4d\xcc\x94\xc5\x79\xab\x1a\xe3\x5a\x7b\x9c\xbb\xa7\xe4\xda\xc0\xf9\x9e\x48\x9f\xf1\x00\x55\x79\xab\x47\xd2\x15\x96\xa7\x62\x8a\xc5\x07\xfd\xfe\x6d\xdd\x83\x69\x57\xe7\x3a\xd2\xa5\xde\x27\x68\xd0\xbb\x12\x72\x83\x7c\x1b\x7d\x43\xcc\x06\x9c\x2c\x46\x50\x52\x81\x22\xd8\xac\xf2\x77\x9c\x4c\x54\x9b\x8a\x80\x01\xe6\xe7\xaf\x41\xf5\x99\xc3\x1a\x57\x58\x7b\x9f\xfa\x07\x03\x8d\x52\x02\x26\xdb\xa8\x86\xd9\x0c\xa2\xa2\xc1\x0b\x4a\xd7\x9d\xa5\x7c\x7c\xb0\xb1\x0e\x16\xd8\x14\x30\xab\x09\x5b\x9b\x0f\x31\x66\x00\x03\xb9\x5f\xe5\x2b\xc1\x36\x12\x8e\x70\xd9\xc3\xb9\x1b\x76\x01\xaa\x34\x0e\x97\xfb\x50\x37\xf5\x4d\xbf\xae\xe1\xa8\xa3\xee\xc9\xde\x45\x67\x36\x11\x2a\x2c\x6e\x7a\x91\x64\x5c\xc7\xc4\x68\xdd\x11\x83\x81\xcd\xd3\x04\x8c\x59\xc0\xe8\x60\x77\xcd\x16\x52\x79\x20\x86\x81\xc6\xfd\x97\xf2\xd2\xa4\x88\x19\x50\xe6\xb0\x5a\xa5\x9f\xd4\xb0\xc2\xd7\x99\xf2\xd1\x22\xac\x9a\x63\x97\x56\x6f\x0f\xc5\x1e\x45\xe6\xad\x8a\x4b\x78\x62\x76\x1f\x8b\x8e\xb6\x2c\x1d\xd9\x77\xa5\xd0\x10\x46\xb8\xd0\xf7\xe5\x47\xa4\x91\xba\xf3\xfd\xbb\x0f\x8a\x82\xdc\xc3\xc2\xca\xef\x75\xf4\x7f\x76\x50\x3f\x5e\x1f\x4c\xc2\x7b\xbc\x13\x1c\x3e\x84\x66\x85\x41\x2b\x7e\x24\x80\x44\xac\xc6\xf6\xfd\x6e\x05\x6c\xa3\x52\x35\x08\x2f\x32\x5d\x6d\x98\x04\xc8\x62\x1c\x1f\x97\x8d\xfc\x10\xb9\x0e\xd4\x43\xfb\x57\x8f\x71\x17\x25\x08\x7b\xe7\x59\x36\x6c\xea\xef\x8c\x3f\xb2\x84\x6d\x76\x83\x7b\xdc\x5d\x1c\x7b\xab\xbf\xbd\x3c\xe5\x87\xe0\xca\x88\x6d\x32\x15\x44\xb6\xd9\x50\x30\xb7\x2d\xea\xe3\x43\xed\xf3\x80\xd1\x82\xf4\x47\xe6\x49\xbf\x95\xbd\xe5\xe9\x91\x8b\x50\xc8\x8a\x5e\x42\xb2\xf6\x42\xa9\x32\x33\x5b\x42\xb8\xf8\xcd\xb7\xaa\xde\x05\x5e\x39\x4a\xb7\xa0\xb9\x00\x21\xeb\x25\x8b\xb0\x52\x36\x07\x26\x51\x24\x20\x2c\xfe\x43\xa6\x63\x4f\xc0\x4a\x52\xe8\xd6\x07\x1c\x02\xdd\x1b\xe3\x56\x03\xee\x3c\xb5\x3a\x93\xa3\xd0\xe6\x2c\x5e\x8b\x30\x28\x92\x2e\xe4\x1f\x92\x94\x7e\x05\xf6\x80\xb5\x5c\xe4\x51\xec\x5f\x3f\xd9\x1f\xc1\xbd\xc3\xc6\xfa\x41\x06\x56\xab\xbb\x93\x85\xa7\x51\x30\x53\x4f\x10\x6b\xbf\xb2\x46\xed\xbe\x0d\x45\x84\xc7\x92\xb6\xc4\xc6\x57\x16\x33\x4e\x08\x89\xeb\xa2\xc8\x8f\x22\xd5\x10\xd2\x11\xf5\xc8\x1c\xa4\x2e\x71\xee\xbe\xf2\xeb\x8e\x25\x0b\x2e\x23\x6a\x8c\xac\x48\x83\x9a\xd2\xa5\x73\xc8\xa3\xc4\x9e\xd9\x67\xca\x63\xa9\x44\x72\x86\x42\x10\x2b\xfd\x1b\xae\xf6\xc1\xba\x3f\x28\x12\x81\x7a\x4f\xde\x7d\xc9\x45\x3f\x6d\xc4\x32\xa8\x07\x2b\x86\x6b\x0f\xf8\xb3\x7b\x4c\x02\x3b\x1a\x5a\x31\xd4\xce\xbb\x8e\x3f\x67\xe2\x93\xae\xdb\xd4\x2f\x3f\x6d\x4a\x89\x19\x6d\x1e\xcc\x35\xb0\x43\x54\x5b\xa1\x86\xd4\x95\xc6\x2b\xc9\x99\x30\xd3\x27\x82\x09\xb7\x6e\x82\x62\xbb\x87\x06\x5f\x34\x92\x3b\xfe\x5c\xe7\x2f\x80\xb9\x7d\x2e\x1d\x9f\x84\x28\xd4\xb1\x03\xf8\xc4\xf2\x61\xbf\x2c\x41\x25\xf9\xf8\x84\x8c\x71\x16\x5d\xe6\xd8\xa5\xa8\xbb\xe2\x64\x6b\x92\x10\xbb\x89\xa2\xfe\xbc\x3b\x75\x27\x42\x15\xd5\xa7\x4f\x59\x6d\xe9\x6e\x60\xe1\x7b\x5e\x8e\x03\xec\x5a\xab\x0d\x1c\xae\x75\xd0\x67\x1c\x98\xd0\x2b\x9a\xc6\x87\x8c\x47\x71\x4b\xb9\xfa\xf9\xfd\x6f\xaa\x2d\x1b\x9d\xdd\xd9\x97\x9f\xda\x16\x8d\x67\xee\xf1\x53\x9c\x25\x61\xe3\x21\xe5\x00\x64\x0c\xd8\x57\x2d\xc4\x07\x98\x83\xff\xa5\xdf\xe1\x33\xb5\x18\x6f\xe2\xaa\x58\x1f\xd2\xc8\xb4\xe2\x75\x52\x72\xa1\xfa\xcf\xa2\xc1\xd9\x18\xb1\xa5\x45\xd7\x26\x33\x98\xe8\x83\x53\x6c\x2f\x67\x45\xb8\x1e\x0d\x44\x46\x43\x97\xc9\xff\x47\xd2\xca\x07\xaf\xbd\x59\x1f\x56\x33\x90\x50\xb9\x91\x52\x07\xbc\xd8\x73\xbd\x0e\x45\x2a\x5c\xd7\x42\x12\x5b\x95\x8d\x98\x59\x73\x55\x3d\x2c\xbf\x3d\xdf\xd9\xef\x11\xc6\xf1\xa5\xa6\x69\x07\x8f\x2a\xa9\xe1\x23\x32\xe1\xe9\x2c\x61\xc3\x49\x86\x5a\x4f\xe7\x1a\xd8\xdc\xea\xe6\xef\x69\x23\xa5\x38\x39\x08\x0b\xf4\xc8\xe9\x4b\x2f\xfc\x2d\xa1\x73\xf3\x0a\xb9\xaa\x5b\xd6\x47\x90\xf3\x6c\x66\x53\x49\x7a\x12\x57\xb9\x95\x9d\x15\x9b\x28\x9e\x5e\xe6\x55\x7a\x81\x68\xef\xbf\x8e\x0e\x03\x23\xa1\x89\x68\x1d\xcc\xd6\x63\x99\x7b\xb5\xdd\x4d\xbe\x74\x10\x49\xa8\x79\xaa\x9c', 2)

# cleanup
del pyarmor_runtime

